<?php

/**
 * Kontin Theme Customizer
 *
 * @package kontin
 */


$kontin_config_id = 'kontin_customize';

Kirki::add_config($kontin_config_id, array(
	'capability'    => 'edit_theme_options',
	'option_type'   => 'theme_mod',
));


/**
 * theme option panel master
 */

Kirki::add_panel('kontin_theme_opt', array(
	'priority'    => 240,
	'title'       => esc_html__('Kontin Options', 'kontin'),
	'description' => esc_html__('Kontin Theme options panel', 'kontin'),
));

/**
 * General options
 */
Kirki::add_section('kontin_theme_general', array(
	'title'          => esc_html__('General Settings', 'kontin'),
	'description'    => esc_html__('Kontin General Settings.', 'kontin'),
	'panel'          => 'kontin_theme_opt',
	'priority'       => 160,
));


// theme base color
Kirki::add_field($kontin_config_id, [
	'type'        => 'color',
	'settings'    => 'theme_base_color',
	'label'       => __('Select Theme Base color', 'kontin'),
	'section'     => 'kontin_theme_general',
	'default'     => sanitize_hex_color('#fba919'),
]);


// theme black color
Kirki::add_field($kontin_config_id, [
	'type'        => 'color',
	'settings'    => 'theme_black_color',
	'label'       => __('Select Theme Black color', 'kontin'),
	'section'     => 'kontin_theme_general',
	'default'     => sanitize_hex_color('#1e1e22'),
]);

// general options fields

Kirki::add_field($kontin_config_id, [
	'type'        => 'checkbox',
	'settings'    => 'preloader',
	'label'       => esc_html__('Preloader Visibility', 'kontin'),
	'section'     => 'kontin_theme_general',
	'default'     => false,
	'priority'    => 10
]);





Kirki::add_field($kontin_config_id, [
	'type'        => 'checkbox',
	'settings'    => 'scroll_to_top',
	'label'       => esc_html__('Back to top Visibility', 'kontin'),
	'section'     => 'kontin_theme_general',
	'default'     => false,
	'priority'    => 10
]);

Kirki::add_field($kontin_config_id, [
	'type'        => 'select',
	'settings'    => 'scroll_to_top_icon',
	'label'       => esc_html__('Select Back to top icon', 'kontin'),
	'section'     => 'kontin_theme_general',
	'default'     => 'fa-angle-up',
	'priority'    => 10,
	'multiple'    => 0,
	'choices'     => kontin_get_fa_icons(),
	'active_callback'  => function () {
		$switch_value = get_theme_mod('scroll_to_top', true);

		if (true === $switch_value) {
			return true;
		}
		return false;
	},
]);




// background image
Kirki::add_field($kontin_config_id, [
	'type'        => 'image',
	'settings'    => 'preloader_image',
	'label'       => esc_html__('Custom Preloader Image', 'kontin'),
	'section'     => 'kontin_theme_general',
]);

// background image
Kirki::add_field($kontin_config_id, [
	'type'        => 'image',
	'settings'    => 'error_404_image',
	'label'       => esc_html__('Custom 404 Image', 'kontin'),
	'section'     => 'kontin_theme_general',
]);

// page header background image
Kirki::add_field($kontin_config_id, [
	'type'        => 'image',
	'settings'    => 'page_header_bg_image',
	'label'       => esc_html__('Page Header Background Image', 'kontin'),
	'section'     => 'kontin_theme_general',
]);



/**
 * Header options
 */

Kirki::add_section('kontin_theme_header', array(
	'title'          => esc_html__('Header Settings', 'kontin'),
	'description'    => esc_html__('Kontin Header Settings.', 'kontin'),
	'panel'          => 'kontin_theme_opt',
	'priority'       => 160,
));



// set logo width
Kirki::add_field($kontin_config_id, [
	'type'        => 'text',
	'settings'    => 'header_logo_width',
	'label'       => __('Add Logo size in px', 'kontin'),
	'section'     => 'kontin_theme_header',
	'default'     => esc_html(198),
]);



// stricky switch
Kirki::add_field($kontin_config_id, [
	'type'        => 'checkbox',
	'settings'    => 'header_stricked_menu',
	'label'       => esc_html__('Stricky Header', 'kontin'),
	'section'     => 'kontin_theme_header',
	'description'    => esc_html__('If you are logged in and your top WordPress Admin bar is active this setting will not effect. But while logged out you will see your sticky menu is toggling by this', 'kontin'),
	'default'     => true,
	'priority'    => 10,
]);


// header banner breadcrumb
Kirki::add_field($kontin_config_id, [
	'type'        => 'switch',
	'settings'    => 'breadcrumb_opt',
	'label'       => esc_html__('Breadcrumb Visibility', 'kontin'),
	'section'     => 'kontin_theme_header',
	'default'     => 'on',
	'priority'    => 10,
	'choices'     => [
		'on'  => esc_html__('Enable', 'kontin'),
		'off' => esc_html__('Disable', 'kontin'),
	],
]);



// Footer options fields
Kirki::add_field($kontin_config_id, [
	'type'        => 'checkbox',
	'settings'    => 'header_custom',
	'label'       => esc_html__('Enable Custom Header', 'kontin'),
	'section'     => 'kontin_theme_header',
	'default'     => false,
	'priority'    => 10,
]);

// Get Footer Custom Post
Kirki::add_field($kontin_config_id, [
	'type'        => 'select',
	'settings'    => 'header_custom_post',
	'label'       => esc_html__('Select Header Type', 'kontin'),
	'choices'     => kontin_post_query('header'),
	'section'     => 'kontin_theme_header',
	'priority'    => 10,
	'active_callback' => function () {
		if (true == post_type_exists('header') && true == get_theme_mod('header_custom')) {
			return true;
		} else {
			return false;
		}
	},
]);


/**
 * Mobile Menu
 */

Kirki::add_section('kontin_theme_mobile_menu', array(
	'title'          => esc_html__('Mobile Menu Settings', 'kontin'),
	'description'    => esc_html__('Kontin Mobile Menu Settings.', 'kontin'),
	'panel'          => 'kontin_theme_opt',
	'priority'       => 160,
));

Kirki::add_field($kontin_config_id, [
	'type'     => 'text',
	'settings' => 'kontin_mobile_menu_email',
	'label'    => esc_html__('Email', 'kontin'),
	'section'  => 'kontin_theme_mobile_menu',
	'default'  => esc_html__('needhelp@kontin.com', 'kontin'),
	'priority' => 10,
]);

Kirki::add_field($kontin_config_id, [
	'type'     => 'image',
	'settings' => 'kontin_mobile_menu_logo',
	'label'    => esc_html__('Logo', 'kontin'),
	'section'  => 'kontin_theme_mobile_menu',
	'priority' => 10,
]);

Kirki::add_field($kontin_config_id, [
	'type'     => 'text',
	'settings' => 'kontin_mobile_menu_phone',
	'label'    => esc_html__('Phone', 'kontin'),
	'section'  => 'kontin_theme_mobile_menu',
	'default'  => esc_html__('666 888 0000', 'kontin'),
	'priority' => 10,
]);

Kirki::add_field($kontin_config_id, [
	'type'        => 'repeater',
	'label'       => esc_html__('Select Social Icons', 'kontin'),
	'section'     => 'kontin_theme_mobile_menu',
	'priority'    => 10,
	'row_label' => [
		'type'  => 'text',
		'value' => esc_html__('Social Icons', 'kontin'),
	],
	'button_label' => esc_html__('Add new Icon', 'kontin'),
	'settings'     => 'mobile_menu_social_icons',
	'default'      => [
		[
			'link_icon' => 'fa-facebook',
			'link_url' => esc_url('http://facebook.com'),
		],
	],
	'fields' => [
		'link_icon'  => [
			'type'        => 'select',
			'label'       => esc_html__('Social Icon', 'kontin'),
			'description' => esc_html__('Select Social Icons', 'kontin'),
			'default'     => 'fa-facebook',
			'choices'     => kontin_get_fa_icons(),
		],
		'link_url' => [
			'type'        => 'text',
			'label'       => esc_html__('Link Url', 'kontin'),
			'description' => esc_html__('Add social profile links', 'kontin'),
			'default'     => esc_url('https://facebook.com/'),
		],
	]
]);




/**
 * Footer options
 */

Kirki::add_section('kontin_theme_footer', array(
	'title'          => esc_html__('Footer Settings', 'kontin'),
	'description'    => esc_html__('Kontin Footer Settings.', 'kontin'),
	'panel'          => 'kontin_theme_opt',
	'priority'       => 160,
));



Kirki::add_field($kontin_config_id, [
	'type'     => 'text',
	'settings' => 'footer_copytext',
	'label'    => esc_html__('Text Control', 'kontin'),
	'section'  => 'kontin_theme_footer',
	'default'  => esc_html__('&copy; All right reserved', 'kontin'),
	'priority' => 10,
	'sanitize_callback' => function ($input) {
		return wp_kses($input, 'kontin_allowed_tags');;
	},
	'active_callback' => function () {
		if (false == get_theme_mod('footer_custom')) {
			return true;
		}
	},
]);


// Footer options fields
Kirki::add_field($kontin_config_id, [
	'type'        => 'checkbox',
	'settings'    => 'footer_custom',
	'label'       => esc_html__('Enable Custom Footer', 'kontin'),
	'section'     => 'kontin_theme_footer',
	'default'     => false,
	'priority'    => 10,
]);

// Get Footer Custom Post
Kirki::add_field($kontin_config_id, [
	'type'        => 'select',
	'settings'    => 'footer_custom_post',
	'label'       => esc_html__('Select Footer Type', 'kontin'),
	'choices'     => kontin_post_query('footer'),
	'section'     => 'kontin_theme_footer',
	'priority'    => 10,
	'active_callback' => function () {
		if (true == post_type_exists('footer') && true == get_theme_mod('footer_custom')) {
			return true;
		} else {
			return false;
		}
	},
]);




/**
 * Service Sidebar Menu
 */


Kirki::add_section('kontin_theme_service_sidebar', array(
	'title'          => esc_html__('Service Sidebar Menu', 'kontin'),
	'description'    => esc_html__('Kontin Service Sidebar Options.', 'kontin'),
	'panel'          => 'kontin_theme_opt',
	'priority'       => 160,
	'active_callback' => function () {
		if (true == post_type_exists('service')) {
			return true;
		}
	},
));


Kirki::add_field($kontin_config_id, [
	'type'     => 'select',
	'settings' => 'kontin_sidebar_menu_item',
	'label'    => esc_html__('Add Nav Menu', 'kontin'),
	'section'  => 'kontin_theme_service_sidebar',
	'priority' => 10,
	'choices'     => kontin_get_nav_menu(),
]);

/**
 * Service Sidebar Contact
 */


Kirki::add_section('kontin_theme_contact_sidebar', array(
	'title'          => esc_html__('Service Sidebar Contact', 'kontin'),
	'description'    => esc_html__('Kontin Service Sidebar Options.', 'kontin'),
	'panel'          => 'kontin_theme_opt',
	'priority'       => 160,
	'active_callback' => function () {
		if (true == post_type_exists('service')) {
			return true;
		}
	},
));

Kirki::add_field($kontin_config_id, [
	'type'     => 'text',
	'settings' => 'kontin_sidebar_contact_title',
	'label'    => esc_html__('Contact Title', 'kontin'),
	'section'  => 'kontin_theme_contact_sidebar',
	'default'  => esc_html__('Need Kontin Help?', 'kontin'),
	'priority' => 10,
	'sanitize_callback' => function ($input) {
		return wp_kses($input, 'kontin_allowed_tags');;
	},
]);

Kirki::add_field($kontin_config_id, [
	'type'     => 'textarea',
	'settings' => 'kontin_sidebar_contact_text',
	'label'    => esc_html__('Contact Text', 'kontin'),
	'section'  => 'kontin_theme_contact_sidebar',
	'default'  => esc_html__('Default Text', 'kontin'),
	'priority' => 10,
	'sanitize_callback' => function ($input) {
		return wp_kses($input, 'kontin_allowed_tags');;
	},
]);

Kirki::add_field($kontin_config_id, [
	'type'     => 'textarea',
	'settings' => 'kontin_sidebar_contact_tagline',
	'label'    => esc_html__('Contact Tagline', 'kontin'),
	'section'  => 'kontin_theme_contact_sidebar',
	'default'  => esc_html__('Default Text', 'kontin'),
	'priority' => 10,
	'sanitize_callback' => function ($input) {
		return wp_kses($input, 'kontin_allowed_tags');;
	},
]);

Kirki::add_field($kontin_config_id, [
	'type'     => 'text',
	'settings' => 'kontin_sidebar_contact_number',
	'label'    => esc_html__('Contact Number', 'kontin'),
	'section'  => 'kontin_theme_contact_sidebar',
	'default'  => esc_html__('666 888 000', 'kontin'),
	'priority' => 10,
	'sanitize_callback' => function ($input) {
		return wp_kses($input, 'kontin_allowed_tags');;
	},
]);

Kirki::add_field($kontin_config_id, [
	'type'     => 'text',
	'settings' => 'kontin_sidebar_contact_number_link',
	'label'    => esc_html__('Contact Number Link', 'kontin'),
	'section'  => 'kontin_theme_contact_sidebar',
	'default'  => esc_html__('#', 'kontin'),
	'priority' => 10,
]);
